# cli/label.py
import json
import requests
from .auth import get_headers
from .utils import handle_response, API_ENDPOINT

def get_labels(check_s3=False):
    try:
        headers = get_headers()
        url = f"{API_ENDPOINT}/label"
        if check_s3:
            url += "?check_s3=true"
        response = requests.get(url, headers=headers)
        response.raise_for_status()
        return handle_response(response)
    except requests.exceptions.HTTPError as e:
        print(f"HTTP error: {e}")
        return {"error": str(e)}
    except Exception as e:
        print(f"Error getting labels: {e}")
        return {"error": str(e)}

def delete_label(label):
    try:
        headers = get_headers()
        response = requests.delete(f"{API_ENDPOINT}/label/{label}", headers=headers)
        response.raise_for_status()
        return handle_response(response)
    except requests.exceptions.HTTPError as e:
        print(f"HTTP error: {e}")
        return {"error": str(e)}
    except Exception as e:
        print(f"Error deleting label: {e}")
        return {"error": str(e)}

def handle_label_command(args):
    if args.label_command == "list":
        result = get_labels(check_s3=args.check_s3)
        if 'error' not in result:
            print("Labels:")
            for label_info in result['labels']:
                if isinstance(label_info, dict):
                    label = label_info['label']
                    exists_in_s3 = label_info.get('exists_in_s3', 'Unknown')
                    print(f"  {label} (Exists in S3: {exists_in_s3})")
                else:
                    print(f"  {label_info}")
        else:
            print(f"Error listing labels: {result['error']}")
    elif args.label_command == "delete":
        result = delete_label(args.label)
        if 'error' not in result:
            print(f"Successfully deleted label: {args.label}")
        else:
            print(f"Error deleting label: {result['error']}")